package com.ruoyi.kaohe.service;

import java.util.List;
import com.ruoyi.kaohe.domain.KhPcEmp;

/**
 * 评测与职工Service接口
 * 
 * @author hs
 * @date 2025-06-17
 */
public interface IKhPcEmpService 
{
    /**
     * 查询评测与职工
     * 
     * @param id 评测与职工主键
     * @return 评测与职工
     */
    public KhPcEmp selectKhPcEmpById(Long id);

    /**
     * 查询评测与职工列表
     * 
     * @param khPcEmp 评测与职工
     * @return 评测与职工集合
     */
    public List<KhPcEmp> selectKhPcEmpList(KhPcEmp khPcEmp);

    /**
     * 新增评测与职工
     * 
     * @param khPcEmp 评测与职工
     * @return 结果
     */
    public int insertKhPcEmp(KhPcEmp khPcEmp);

    /**
     * 修改评测与职工
     * 
     * @param khPcEmp 评测与职工
     * @return 结果
     */
    public int updateKhPcEmp(KhPcEmp khPcEmp);

    /**
     * 批量删除评测与职工
     * 
     * @param ids 需要删除的评测与职工主键集合
     * @return 结果
     */
    public int deleteKhPcEmpByIds(Long[] ids);

    /**
     * 删除评测与职工信息
     * 
     * @param id 评测与职工主键
     * @return 结果
     */
    public int deleteKhPcEmpById(Long id);
}
