package com.ruoyi.kaohe.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.kaohe.domain.KhPcEmp;
import com.ruoyi.kaohe.service.IKhPcEmpService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 评测与职工Controller
 * 
 * @author hs
 * @date 2025-06-17
 */
@RestController
@RequestMapping("/kaohe/pc_emp")
public class KhPcEmpController extends BaseController
{
    @Autowired
    private IKhPcEmpService khPcEmpService;

    /**
     * 查询评测与职工列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:pc_emp:list')")
    @GetMapping("/list")
    public TableDataInfo list(KhPcEmp khPcEmp)
    {
        startPage();
        List<KhPcEmp> list = khPcEmpService.selectKhPcEmpList(khPcEmp);
        return getDataTable(list);
    }

    /**
     * 导出评测与职工列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:pc_emp:export')")
    @Log(title = "评测与职工", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KhPcEmp khPcEmp)
    {
        List<KhPcEmp> list = khPcEmpService.selectKhPcEmpList(khPcEmp);
        ExcelUtil<KhPcEmp> util = new ExcelUtil<KhPcEmp>(KhPcEmp.class);
        util.exportExcel(response, list, "评测与职工数据");
    }

    /**
     * 获取评测与职工详细信息
     */
    @PreAuthorize("@ss.hasPermi('kaohe:pc_emp:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(khPcEmpService.selectKhPcEmpById(id));
    }

    /**
     * 新增评测与职工
     */
    @PreAuthorize("@ss.hasPermi('kaohe:pc_emp:add')")
    @Log(title = "评测与职工", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KhPcEmp khPcEmp)
    {
        return toAjax(khPcEmpService.insertKhPcEmp(khPcEmp));
    }

    /**
     * 修改评测与职工
     */
    @PreAuthorize("@ss.hasPermi('kaohe:pc_emp:edit')")
    @Log(title = "评测与职工", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KhPcEmp khPcEmp)
    {
        return toAjax(khPcEmpService.updateKhPcEmp(khPcEmp));
    }

    /**
     * 删除评测与职工
     */
    @PreAuthorize("@ss.hasPermi('kaohe:pc_emp:remove')")
    @Log(title = "评测与职工", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(khPcEmpService.deleteKhPcEmpByIds(ids));
    }
}
